@@ -3,6 +3,8 @@
 
 from __future__ import print_function
 
+import gi
+gi.require_version("Gtk", "3.0")
 from gi.repository import Gtk, GLib
 
 import atexit
@@ -14,7 +16,6 @@ import subprocess
 import sys
 import time
 import unittest
-import pathlib
 
 sys.path.insert(0, "../")
 from softwareproperties.dbus.SoftwarePropertiesDBus import (
@@ -46,9 +47,6 @@ def create_sources_list():
     s = get_test_source_line() + "\n"
     name = os.path.join(os.path.dirname(__file__),
                         "aptroot", "etc", "apt", "sources.list")
-    dirname = os.path.dirname(name)
-    if not os.path.exists(dirname):
-        pathlib.Path(dirname).mkdir(parents=True)
     with open(name, "w") as f:
         f.write(s)
     return name
@@ -314,7 +312,8 @@ class TestDBus(unittest.TestCase):
         # remove the key 
         res = self.iface.RemoveKey("D732CA59")
         self.assertTrue(res)
-        self.assertEqual(os.path.getsize(trusted_gpg), 0)
+        if os.path.exists(trusted_gpg):
+            self.assertEqual(os.path.getsize(trusted_gpg), 0)
         # add from data
         with open(testkey) as keyfile:
             data = keyfile.read()
@@ -325,7 +324,8 @@ class TestDBus(unittest.TestCase):
         # remove the key 
         res = self.iface.RemoveKey("D732CA59")
         self.assertTrue(res)
-        self.assertEqual(os.path.getsize(trusted_gpg), 0)
+        if os.path.exists(trusted_gpg):        
+            self.assertEqual(os.path.getsize(trusted_gpg), 0)
         # test nonsense
         res = self.iface.AddKeyFromData("nonsens")
         self.assertFalse(res)
